Project Roadmap
===============

- [X] ``Task 1``: <strike>Run PIC simulation using several field solvers.</strike>
- [X] ``Task 2``: <strike>Finalize example scripts and their documentation.</strike>
- [X] ``Task 3``: <strike>Implement a relativistic equation of motion.</strike>
- [ ] ``Task 4``: Implement collisions to allow the plasma to relax to a Maxwellian.
- [ ] ``Task 5``: Implement guiding-center equations of motion.
- [ ] ``Task 6``: Implement an implicit time-stepping algorithm.
- [ ] ``Task 7``: Generalize JAX-in-Cell to 2D.
